      SUBROUTINE MAP_STEEL_NANOAL(ALTOT,OXYWT,TITOT,NITPPM,BWT,STATE,
     &          FBORT,CONST,IYES,IAL,IOX,ALSOL,PPMBG1,PPMBG2,PPMBSL,
     &          NITSOL,PPMOAL,PPMOTI,PPMOMN,PPMOSI,PPMTIO,PPMTIN,PPMBN,
     &          OXYMIN,OXY3,OXY4,OXY5,GALAX)
C
C ALTOT total aluminium, wt.%
C ALSOL soluble aluminium, wt.%
C ALSOLC critical value of ALSOL, below which microstructure safe
C GALAX ratio of wt. O with Al to O with Mn; should be 3 or less to ensure
C  galaxite rather than gamma-alumina
C OXYWT   total oxygen, wt.%
C OXY1   oxygen left over after aluminium has reacted
C OXY2   oxygen left over after aluminium & titanium have reacted
C        Alumina = Al2O3, titania = Ti2O3, TiO or TiO2
C OXY3 extra oxygen needed in order to fully react the Al and Ti, wt.%
C OXYMIN minimum oxygen, wt.% to combine with Al and Ti
C OXY4 minimum oxygen to ensure intragranular nucleation
C OXY5 upper bound to oxygen level = OXY4 + 0.01
C IAL integer=1 if calculation out of bounds of empirical equation
C IOX integer=1 if calculation out of bounds of empirical equation
C PEROAL  % of moles of oxygen tied up with aluminium
C PEROTI  % of moles of oxygen tied up with titanium
C PEROSI & PEROMN   % of moles of oxygen tied up with SiO2, MnO
C PPMBSL soluble boron in ppm by wt.
C PPMBG1, PPMBG2 boron soluble in austenite at 900C, 1000C ppm by wt.
C
      IMPLICIT NONE                           
      DOUBLE PRECISION ALSOL,ALTOT,BWT,CONST,FBORT,GALAX
      DOUBLE PRECISION OXY3,OXY4,OXY5,OXYMIN,OXYWT,NITPPM,NITSOL
      DOUBLE PRECISION PERBN,PERBSL,PEROAL,PEROMN,PEROSI,PEROTI
      DOUBLE PRECISION PERTIN,PERTIO,PPMBG1,PPMBG2,PPMBN,PPMBSL,PPMOAL 
      DOUBLE PRECISION PPMOMN,PPMOSI,PPMOTI,PPMTIN,PPMTIO,STATE,TITOT
      DOUBLE PRECISION ALSOLC,NITWT,R,T0
      INTEGER IAL,IOX
      INTEGER IU,MAXI,IYES,IFAILB1,IFAILB2
C
C  R is the molar gas constant (in Joules per mole per Kelvin, J/(mol K))
C
      R=8.31451D+00
C
C MAXI is the maximum number of iterations to be performed in MAP_STEEL_ALUM
C
      MAXI   = 20
      ALSOLC = 0.006D0
      T0     = 273.15D0
      NITWT  = NITPPM*1.0D-4
C
C This part is probably redundant now since soluble boron never gets
C to these limits.
C Note that there are two solublity products being used in the program,
C one due to Fountain and Chipman, the other in subroutine BORON.
C This needs to be rationalised.
C
C Call MAP_STEEL_BORON to find the solubility of boron in austenite 
C at 900 and 1000 deg. Centigrade:
C
      CALL MAP_STEEL_BORON(PPMBG1,T0+905.0D0,IFAILB1,R)
      CALL MAP_STEEL_BORON(PPMBG2,T0+1000.0D0,IFAILB2,R)
C
C Estimate the amount of Al that remains in solid solution in the ferrite:
C
      IAL = 0
      CALL MAP_STEEL_ALUM(OXYWT,ALTOT,ALSOL,MAXI,IU,IAL,CONST)
      IF ( IU.GE.MAXI ) IAL = IAL + 10
C
C Call PARTIC to calculate the distribution of oxygen and nitrogen amoungst
C the elements Al, Ti, B, Si and Mn.
C
      CALL MAP_STEEL_PARTIC(ALTOT,ALSOL,OXYWT,OXYMIN,TITOT,PEROAL,
     &     PEROTI,PEROMN,PEROSI,PERTIN,PERTIO,PERBSL,PERBN,IOX,NITWT,
     &     NITSOL,BWT,STATE,FBORT)
C
      GALAX = 0D0
      IF (PEROMN .GT. 0.0D0) GALAX=PEROAL/PEROMN
      OXY3 = OXYMIN-OXYWT
      IF (IYES .EQ. 0) OXY4 = 0.012D+00
      IF (IYES .EQ. 1) OXY4 = OXYMIN
      OXY5 = OXY4 + 0.01D0
      PPMOAL = PEROAL*1.0D2*OXYWT
      PPMOTI = PEROTI*1.0D2*OXYWT
      PPMOMN = PEROMN*1.0D2*OXYWT
      PPMOSI = PEROSI*1.0D2*OXYWT
      PPMTIN = PERTIN*1.0D2*TITOT
      PPMTIO = PERTIO*1.0D2*TITOT
      PPMBSL = PERBSL*1.0D2*BWT
      PPMBN  = PERBN *1.0D2*BWT
      RETURN
      END
